==> packageinstaller-pkglist_0.3.28.tar.xz: packageinstaller-pkglist/slimjet_64.pm <==
<?xml version="1.0"?>
<app>

<category>
Browser
</category>

<name>  
Slimjet
</name>

<description>  
   <am>Latest Slimjet Browser (run again for updates)</am>
   <ar>Latest Slimjet Browser (run again for updates)</ar>
   <bg>Latest Slimjet Browser (run again for updates)</bg>
   <bn>Latest Slimjet Browser (run again for updates)</bn>
   <ca>Darrer navegador Slimjet (torneu a executar-lo per actualitzacions)</ca>
   <cs>Latest Slimjet Browser (run again for updates)</cs>
   <da>Seneste Slimjet-browser (kør igen for opdateringer)</da>
   <de>Neuester Slimjet Browser (zur Aktualisierung erneut ausführen)</de>
   <el>Τελευταίο πρόγραμμα περιήγησης Slimjet (εκτελείται ξανά για ενημερώσεις)</el>
   <en>Latest Slimjet Browser (run again for updates)</en>
   <es>El Último Navegador Slimjet (ejecutar de nuevo para las actualizaciones)</es>
   <et>Latest Slimjet Browser (run again for updates)</et>
   <eu>Latest Slimjet Browser (run again for updates)</eu>
   <fa>Latest Slimjet Browser (run again for updates)</fa>
   <fil_PH>Latest Slimjet Browser (run again for updates)</fil_PH>
   <fi>Latest Slimjet Browser (run again for updates)</fi>
   <fr>La dernière version du navigateur Slimjet (relancer pour mise à jour)</fr>
   <he_IL>Latest Slimjet Browser (run again for updates)</he_IL>
   <hi>Latest Slimjet Browser (run again for updates)</hi>
   <hr>Latest Slimjet Browser (run again for updates)</hr>
   <hu>Latest Slimjet Browser (run again for updates)</hu>
   <id>Latest Slimjet Browser (run again for updates)</id>
   <is>Latest Slimjet Browser (run again for updates)</is>
   <it>Ultima versione del browser Slimjet (avvia nuovamente per gli aggiornamenti)</it>
   <ja_JP>Latest Slimjet Browser (run again for updates)</ja_JP>
   <ja>Latest Slimjet Browser (run again for updates)</ja>
   <kk>Latest Slimjet Browser (run again for updates)</kk>
   <ko>Latest Slimjet Browser (run again for updates)</ko>
   <lt>Latest Slimjet Browser (run again for updates)</lt>
   <mk>Latest Slimjet Browser (run again for updates)</mk>
   <mr>Latest Slimjet Browser (run again for updates)</mr>
   <nb>Latest Slimjet Browser (run again for updates)</nb>
   <nl>Meest recente Slimjet Browser (nogmaals uitvoeren voor updates)</nl>
   <pl>najnowsza przeglądarka Slimjet (uruchom ponownie w celu aktualizacji)</pl>
   <pt_BR>Navegador web Slimjet, versão mais recente (para obter atualizações, se disponíveis, voltar a executar)</pt_BR>
   <pt>Navegador web Slimjet, versão mais recente (para obter actualizações, se disponíveis, voltar a executar)</pt>
   <ro>Latest Slimjet Browser (run again for updates)</ro>
   <ru>Браузер Slimjet последней версии (перезапустите для установки обновлений)</ru>
   <sk>Latest Slimjet Browser (run again for updates)</sk>
   <sl>Zadnja različica Slimjet brskalnika</sl>
   <sq>Latest Slimjet Browser (run again for updates)</sq>
   <sr>Latest Slimjet Browser (run again for updates)</sr>
   <sv>Senaste Slimjet Webbläsare (kör igen för uppdateringar)</sv>
   <tr>Latest Slimjet Browser (run again for updates)</tr>
   <uk>Latest Slimjet Browser (run again for updates)</uk>
   <vi>Latest Slimjet Browser (run again for updates)</vi>
   <zh_CN>Latest Slimjet Browser (run again for updates)</zh_CN>
   <zh_TW>Latest Slimjet Browser (run again for updates)</zh_TW>
</description>

<installable>
64
</installable>

<screenshot>https://www.slimjet.com/en/images/newtab.jpg</screenshot>

<preinstall>
wget http://www.slimjet.com/release/slimjet_amd64.deb
dpkg -i slimjet*.deb
apt-get -f install
</preinstall>

<install_package_names>

</install_package_names>


<postinstall>
rm slimjet*.deb
</postinstall>


<uninstall_package_names>
slimjet
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/slimjet_64.pm <==
<?xml version="1.0"?>
<app>

<category>
Browser
</category>

<name>
Slimjet
</name>

<description>
   <am>Latest Slimjet Browser (run again for updates)</am>
   <ar>Latest Slimjet Browser (run again for updates)</ar>
   <be>Latest Slimjet Browser (run again for updates)</be>
   <bg>Latest Slimjet Browser (run again for updates)</bg>
   <bn>Latest Slimjet Browser (run again for updates)</bn>
   <ca>Darrer navegador Slimjet (torneu a executar-lo per actualitzacions)</ca>
   <cs>Latest Slimjet Browser (run again for updates)</cs>
   <da>Seneste Slimjet-browser (kør igen for opdateringer)</da>
   <de>Neuester Slimjet Browser (zur Aktualisierung erneut ausführen)</de>
   <el>Το τελευταίο πρόγραμμα περιήγησης Slimjet (εκτελείται ξανά για ενημερώσεις)</el>
   <en>Latest Slimjet Browser (run again for updates)</en>
   <es_ES>El Último Navegador Slimjet (ejecutar de nuevo para las actualizaciones)</es_ES>
   <es>El Último Navegador Slimjet (ejecutar de nuevo para las actualizaciones)</es>
   <et>Latest Slimjet Browser (run again for updates)</et>
   <eu>Latest Slimjet Browser (run again for updates)</eu>
   <fa>Latest Slimjet Browser (run again for updates)</fa>
   <fil_PH>Latest Slimjet Browser (run again for updates)</fil_PH>
   <fi>Viimeisin Slimjet-selain (aja uudelleen päivitystentarkistusta varten)</fi>
   <fr_BE>Latest Slimjet Browser (run again for updates)</fr_BE>
   <fr>La dernière version du navigateur Slimjet (relancer pour mise à jour)</fr>
   <gl_ES>Navegador web Slimjet, versión máis recente (para obter actualizacións, se disponibles, volver a executar)</gl_ES>
   <he_IL>Latest Slimjet Browser (run again for updates)</he_IL>
   <hi>Latest Slimjet Browser (run again for updates)</hi>
   <hr>Latest Slimjet Browser (run again for updates)</hr>
   <hu>Latest Slimjet Browser (run again for updates)</hu>
   <id>Latest Slimjet Browser (run again for updates)</id>
   <is>Latest Slimjet Browser (run again for updates)</is>
   <it>Ultima versione del browser Slimjet (avvia nuovamente per gli aggiornamenti)</it>
   <ja>最新の Slimjet ブラウザ (アップデートのため再度実行してください)</ja>
   <kk>Latest Slimjet Browser (run again for updates)</kk>
   <ko>Latest Slimjet Browser (run again for updates)</ko>
   <lt>Latest Slimjet Browser (run again for updates)</lt>
   <mk>Latest Slimjet Browser (run again for updates)</mk>
   <mr>Latest Slimjet Browser (run again for updates)</mr>
   <nb_NO>Latest Slimjet Browser (run again for updates)</nb_NO>
   <nb>Seneste Slimjet-nettleser (kjør igjen for oppdateringer)</nb>
   <nl_BE>Latest Slimjet Browser (run again for updates)</nl_BE>
   <nl>Meest recente Slimjet Browser (nogmaals uitvoeren voor updates)</nl>
   <pl>najnowsza przeglądarka Slimjet (uruchom ponownie w celu aktualizacji)</pl>
   <pt_BR>Slimjet - Versão mais recente do navegador de internet (execute novamente para obter atualizações disponíveis)</pt_BR>
   <pt>Navegador web Slimjet, versão mais recente (para obter actualizações, se disponíveis, voltar a executar)</pt>
   <ro>Latest Slimjet Browser (run again for updates)</ro>
   <ru>Браузер Slimjet последней версии (перезапустите для установки обновлений)</ru>
   <sk>Latest Slimjet Browser (run again for updates)</sk>
   <sl>Zadnja različica Slimjet brskalnika</sl>
   <sq>Latest Slimjet Browser (run again for updates)</sq>
   <sr>Latest Slimjet Browser (run again for updates)</sr>
   <sv>Senaste Slimjet Webbläsare (kör igen för uppdateringar)</sv>
   <th>เบราว์เซอร์ Slimjet ล่าสุด (รันอีกครั้งเพื่ออัปเดต)</th>
   <tr>En son Slimjet Tarayıcı (güncellemeler için tekrar çalıştırın)</tr>
   <uk>Latest Slimjet Browser (run again for updates)</uk>
   <vi>Latest Slimjet Browser (run again for updates)</vi>
   <zh_CN>Latest Slimjet Browser (run again for updates)</zh_CN>
   <zh_HK>Latest Slimjet Browser (run again for updates)</zh_HK>
   <zh_TW>Latest Slimjet Browser (run again for updates)</zh_TW>
</description>

<installable>
64
</installable>

<screenshot>https://www.slimjet.com/en/images/newtab.jpg</screenshot>

<preinstall>
wget http://www.slimjet.com/release/slimjet_amd64.deb
dpkg -i slimjet*.deb
apt-get -f install
</preinstall>

<install_package_names>

</install_package_names>


<postinstall>
rm slimjet*.deb
</postinstall>


<uninstall_package_names>
slimjet
</uninstall_package_names>
</app>
